@@ -78,8 +78,8 @@ class Parser(Processor):
 
 
 def run(args) -> None:
-    logger.enable('cjk-commons')
-    logger.enable('commons-1c')
+    logger.enable('cjk_commons')
+    logger.enable('commons_1c')
     logger.enable(__name__)
 
     try:
